@@ -79,6 +79,7 @@ typedef enum {
 } GdlDockItemBehavior;
 
 
+#ifndef GDL_DISABLE_DEPRECATED
 /**
  * GdlDockItemFlags:
  * @GDL_DOCK_IN_DRAG: item is in a drag operation
@@ -88,6 +89,7 @@ typedef enum {
  *
  * Status flag of a GdlDockItem. Don't use unless you derive a widget from GdlDockItem
  *
+ * Deprecated: 3.6: Use your own private data instead.
  **/
 typedef enum {
     GDL_DOCK_IN_DRAG             = 1 << GDL_DOCK_OBJECT_FLAGS_SHIFT,
@@ -95,6 +97,7 @@ typedef enum {
     GDL_DOCK_ICONIFIED           = 1 << (GDL_DOCK_OBJECT_FLAGS_SHIFT + 2),
     GDL_DOCK_USER_ACTION         = 1 << (GDL_DOCK_OBJECT_FLAGS_SHIFT + 3)
 } GdlDockItemFlags;
+#endif
 
 typedef struct _GdlDockItem             GdlDockItem;
 typedef struct _GdlDockItemPrivate      GdlDockItemPrivate;
@@ -104,15 +107,7 @@ typedef struct _GdlDockItemClassPrivate GdlDockItemClassPrivate;
 struct _GdlDockItem {
     GdlDockObject        object;
 
-    GtkWidget           *child;
-    GdlDockItemBehavior  behavior;
-    GtkOrientation       orientation;
-
-    guint                resize : 1;
-
-    gint                 dragoff_x, dragoff_y;    /* these need to be
-                                                     accesible from
-                                                     outside */
+    /* < private> */
     GdlDockItemPrivate  *priv;
 };
 
@@ -121,8 +116,6 @@ struct _GdlDockItemClass {
 
     GdlDockItemClassPrivate *priv;
 
-    gboolean            has_grip;
-
     /* virtuals */
     void     (* set_orientation)  (GdlDockItem    *item,
                                    GtkOrientation  orientation);
@@ -148,8 +141,10 @@ struct _GdlDockItemClass {
  * Deprecated: 3.6: Use GDL_DOCK_OBJECT_FLAGS instead
  */
 #define GDL_DOCK_ITEM_FLAGS(item)     (GDL_DOCK_OBJECT (item)->flags)
+#endif
 
 
+#ifndef GDL_DISABLE_DEPRECATED
 /**
  * GDL_DOCK_ITEM_SET_FLAGS:
  * @item: A #GdlDockObject
@@ -161,7 +156,9 @@ struct _GdlDockItemClass {
  */
 #define GDL_DOCK_ITEM_SET_FLAGS(item,flag) \
     G_STMT_START { (GDL_DOCK_OBJECT_FLAGS (item) |= (flag)); } G_STMT_END
+#endif
 
+#ifndef GDL_DISABLE_DEPRECATED
 /**
  * GDL_DOCK_ITEM_UNSET_FLAGS:
  * @item: A #GdlDockObject
@@ -173,47 +170,62 @@ struct _GdlDockItemClass {
  */
 #define GDL_DOCK_ITEM_UNSET_FLAGS(item,flag) \
     G_STMT_START { (GDL_DOCK_OBJECT_FLAGS (item) &= ~(flag)); } G_STMT_END
-
 #endif
 
+#ifndef GDL_DISABLE_DEPRECATED
 /**
  * GDL_DOCK_ITEM_IN_DRAG:
  * @item: A #GdlDockObject
  *
  * Evaluates to %TRUE if the user is dragging the item.
+ *
+ * Deprecated: 3.6: Use a private flag instead
  */
 #define GDL_DOCK_ITEM_IN_DRAG(item) \
     ((GDL_DOCK_OBJECT_FLAGS (item) & GDL_DOCK_IN_DRAG) != 0)
+#endif
 
+#ifndef GDL_DISABLE_DEPRECATED
 /**
  * GDL_DOCK_ITEM_IN_PREDRAG:
  * @item: A #GdlDockObject
  *
  * Evaluates to %TRUE if the user has clicked on the item but hasn't made a big
  * enough move to start the drag operation.
+ *
+ * Deprecated: 3.6: Use a private flag instead
  */
 #define GDL_DOCK_ITEM_IN_PREDRAG(item) \
     ((GDL_DOCK_OBJECT_FLAGS (item) & GDL_DOCK_IN_PREDRAG) != 0)
+#endif
 
+#ifndef GDL_DISABLE_DEPRECATED
 /**
  * GDL_DOCK_ITEM_ICONIFIED:
  * @item: A #GdlDockObject
  *
  * Evaluates to %TRUE if the item is iconified, appearing only as a button in
  * the dock bar.
+ *
+ * Deprecated: 3.6: Use GDL_DOCK_OBJECT_UNSET_FLAGS instead
  */
 #define GDL_DOCK_ITEM_ICONIFIED(item) \
     ((GDL_DOCK_OBJECT_FLAGS (item) & GDL_DOCK_ICONIFIED) != 0)
+#endif
 
+#ifndef GDL_DISABLE_DEPRECATED
 /**
  * GDL_DOCK_ITEM_USER_ACTION:
  * @item: A #GdlDockObject
  *
  * Evaluates to %TRUE if the user currently use the item, by example dragging
  * division of a #GdlDockPaned object.
+ *
+ * Deprecated: 3.6: Use a private flag instead
  */
 #define GDL_DOCK_ITEM_USER_ACTION(item) \
     ((GDL_DOCK_OBJECT_FLAGS (item) & GDL_DOCK_USER_ACTION) != 0)
+#endif
 
 /**
  * GDL_DOCK_ITEM_NOT_LOCKED:
@@ -221,16 +233,20 @@ struct _GdlDockItemClass {
  *
  * Evaluates to %TRUE the item can be moved, closed, or iconified.
  */
-#define GDL_DOCK_ITEM_NOT_LOCKED(item) !((item)->behavior & GDL_DOCK_ITEM_BEH_LOCKED)
+#define GDL_DOCK_ITEM_NOT_LOCKED(item) ((gdl_dock_item_get_behavior_flags(item) & GDL_DOCK_ITEM_BEH_LOCKED) == 0)
 
+
+#ifndef GDL_DISABLE_DEPRECATED
 /**
  * GDL_DOCK_ITEM_NO_GRIP:
  * @item: A #GdlDockObject
  *
  * Evaluates to %TRUE the item has not handle, so it cannot be moved.
+ *
+ * Deprecated: 3.6: Use !GDL_DOCK_ITEM_HAS_GRIP instead
  */
-#define GDL_DOCK_ITEM_NO_GRIP(item) ((item)->behavior & GDL_DOCK_ITEM_BEH_NO_GRIP)
-
+#define GDL_DOCK_ITEM_NO_GRIP(item) ((gdl_dock_item_get_behavior_flags(item) & GDL_DOCK_ITEM_BEH_NO_GRIP) != 0)
+#endif
 
 /**
  * GDL_DOCK_ITEM_HAS_GRIP:
@@ -238,8 +254,7 @@ struct _GdlDockItemClass {
  *
  * Evaluates to %TRUE the item has a handle, so it can be moved.
  */
-#define GDL_DOCK_ITEM_HAS_GRIP(item) ((GDL_DOCK_ITEM_GET_CLASS (item)->has_grip)&& \
-		! GDL_DOCK_ITEM_NO_GRIP (item))
+#define GDL_DOCK_ITEM_HAS_GRIP(item) ((gdl_dock_item_get_behavior_flags (item) & GDL_DOCK_ITEM_BEH_NO_GRIP) == 0)
 
 /**
  * GDL_DOCK_ITEM_CANT_CLOSE:
@@ -247,9 +262,7 @@ struct _GdlDockItemClass {
  *
  * Evaluates to %TRUE the item cannot be closed.
  */
-#define GDL_DOCK_ITEM_CANT_CLOSE(item) \
-    ((((item)->behavior & GDL_DOCK_ITEM_BEH_CANT_CLOSE) != 0)|| \
-     ! GDL_DOCK_ITEM_NOT_LOCKED(item))
+#define GDL_DOCK_ITEM_CANT_CLOSE(item) ((gdl_dock_item_get_behavior_flags(item) & GDL_DOCK_ITEM_BEH_CANT_CLOSE) != 0)
 
 /**
  * GDL_DOCK_ITEM_CANT_ICONIFY:
@@ -257,67 +270,89 @@ struct _GdlDockItemClass {
  *
  * Evaluates to %TRUE the item cannot be iconifyed.
  */
-#define GDL_DOCK_ITEM_CANT_ICONIFY(item) \
-    ((((item)->behavior & GDL_DOCK_ITEM_BEH_CANT_ICONIFY) != 0)|| \
-     ! GDL_DOCK_ITEM_NOT_LOCKED(item))
+#define GDL_DOCK_ITEM_CANT_ICONIFY(item) ((gdl_dock_item_get_behavior_flags(item) & GDL_DOCK_ITEM_BEH_CANT_ICONIFY) != 0)
 
 /* public interface */
 
-GtkWidget     *gdl_dock_item_new               (const gchar         *name,
-                                                const gchar         *long_name,
-                                                GdlDockItemBehavior  behavior);
-GtkWidget     *gdl_dock_item_new_with_stock    (const gchar         *name,
-                                                const gchar         *long_name,
-                                                const gchar         *stock_id,
-                                                GdlDockItemBehavior  behavior);
+GtkWidget     *gdl_dock_item_new                   (const gchar         *name,
+                                                    const gchar         *long_name,
+                                                    GdlDockItemBehavior  behavior);
+GtkWidget     *gdl_dock_item_new_with_stock        (const gchar         *name,
+                                                    const gchar         *long_name,
+                                                    const gchar         *stock_id,
+                                                    GdlDockItemBehavior  behavior);
 
-GtkWidget     *gdl_dock_item_new_with_pixbuf_icon (const gchar         *name,
-                                                   const gchar         *long_name,
-                                                   const GdkPixbuf     *pixbuf_icon,
-                                                   GdlDockItemBehavior  behavior);
+GtkWidget     *gdl_dock_item_new_with_pixbuf_icon  (const gchar      *name,
+                                                    const gchar      *long_name,
+                                                    const GdkPixbuf  *pixbuf_icon,
+                                                    GdlDockItemBehavior  behavior);
 
-GType          gdl_dock_item_get_type          (void);
+GType          gdl_dock_item_get_type              (void);
 
-void           gdl_dock_item_dock_to           (GdlDockItem      *item,
-                                                GdlDockItem      *target,
-                                                GdlDockPlacement  position,
-                                                gint              docking_param);
+void           gdl_dock_item_dock_to               (GdlDockItem      *item,
+                                                    GdlDockItem      *target,
+                                                    GdlDockPlacement  position,
+                                                    gint              docking_param);
 
-void           gdl_dock_item_set_orientation   (GdlDockItem    *item,
-                                                GtkOrientation  orientation);
+void           gdl_dock_item_set_orientation       (GdlDockItem      *item,
+                                                    GtkOrientation    orientation);
+GtkOrientation gdl_dock_item_get_orientation       (GdlDockItem      *item);
 
-GtkWidget     *gdl_dock_item_get_tablabel      (GdlDockItem *item);
-void           gdl_dock_item_set_tablabel      (GdlDockItem *item,
-                                                GtkWidget   *tablabel);
-GtkWidget     *gdl_dock_item_get_grip          (GdlDockItem *item);
-void           gdl_dock_item_hide_grip         (GdlDockItem *item);
-void           gdl_dock_item_show_grip         (GdlDockItem *item);
-void           gdl_dock_item_notify_selected   (GdlDockItem *item);
-void           gdl_dock_item_notify_deselected (GdlDockItem *item);
+void           gdl_dock_item_set_behavior_flags    (GdlDockItem      *item,
+                                                    GdlDockItemBehavior behavior,
+                                                    gboolean clear);
+void           gdl_dock_item_unset_behavior_flags  (GdlDockItem      *item,
+                                                    GdlDockItemBehavior behavior);
+GdlDockItemBehavior gdl_dock_item_get_behavior_flags (GdlDockItem      *item);
+
+GtkWidget     *gdl_dock_item_get_tablabel          (GdlDockItem      *item);
+void           gdl_dock_item_set_tablabel          (GdlDockItem      *item,
+                                                    GtkWidget        *tablabel);
+GtkWidget     *gdl_dock_item_get_grip              (GdlDockItem      *item);
+void           gdl_dock_item_hide_grip             (GdlDockItem      *item);
+void           gdl_dock_item_show_grip             (GdlDockItem      *item);
+void           gdl_dock_item_notify_selected       (GdlDockItem      *item);
+void           gdl_dock_item_notify_deselected     (GdlDockItem      *item);
 
 /* bind and unbind items to a dock */
-void           gdl_dock_item_bind              (GdlDockItem *item,
-                                                GtkWidget   *dock);
+void           gdl_dock_item_bind                  (GdlDockItem      *item,
+                                                    GtkWidget        *dock);
 
-void           gdl_dock_item_unbind            (GdlDockItem *item);
+void           gdl_dock_item_unbind                (GdlDockItem      *item);
 
-void           gdl_dock_item_hide_item         (GdlDockItem *item);
+void           gdl_dock_item_hide_item             (GdlDockItem      *item);
 
-void           gdl_dock_item_iconify_item      (GdlDockItem *item);
+void           gdl_dock_item_iconify_item          (GdlDockItem      *item);
 
-void           gdl_dock_item_show_item         (GdlDockItem *item);
+void           gdl_dock_item_show_item             (GdlDockItem      *item);
 
-void           gdl_dock_item_lock              (GdlDockItem *item);
+void           gdl_dock_item_lock                  (GdlDockItem      *item);
 
-void           gdl_dock_item_unlock            (GdlDockItem *item);
+void           gdl_dock_item_unlock                (GdlDockItem      *item);
 
-void        gdl_dock_item_set_default_position (GdlDockItem      *item,
-                                                GdlDockObject    *reference);
+void           gdl_dock_item_set_default_position  (GdlDockItem      *item,
+                                                    GdlDockObject    *reference);
 
-void        gdl_dock_item_preferred_size       (GdlDockItem      *item,
-                                                GtkRequisition   *req);
+void           gdl_dock_item_preferred_size        (GdlDockItem      *item,
+                                                    GtkRequisition   *req);
+void           gdl_dock_item_get_drag_area         (GdlDockItem    *item,
+                                                    GdkRectangle   *rect);
+
+gboolean       gdl_dock_item_or_child_has_focus    (GdlDockItem      *item);
+
+gboolean       gdl_dock_item_is_placeholder        (GdlDockItem      *item);
+
+gboolean       gdl_dock_item_is_closed             (GdlDockItem      *item);
+
+gboolean       gdl_dock_item_is_iconified          (GdlDockItem      *item);
+
+void           gdl_dock_item_set_child             (GdlDockItem      *item,
+                                                    GtkWidget        *child);
+GtkWidget*     gdl_dock_item_get_child             (GdlDockItem      *item);
+
+void           gdl_dock_item_class_set_has_grip    (GdlDockItemClass *item_class,
+                                                    gboolean         has_grip);
 
-gboolean    gdl_dock_item_or_child_has_focus  (GdlDockItem      *item);
 
 G_END_DECLS
 
